Module: Google::Cloud::Bigquery::Storage
- Defined in:
- lib/google/cloud/bigquery/storage.rb,
lib/google/cloud/bigquery/storage/version.rb
Constant Summary collapse
- VERSION =
"1.8.0"
Class Method Summary collapse
-
.big_query_read(version: :v1, &block) ⇒ ::Object
Create a new client object for BigQueryRead.
-
.big_query_read_available?(version: :v1) ⇒ boolean
Determines whether the BigQueryRead service is supported by the current client.
-
.big_query_write(version: :v1, &block) ⇒ ::Object
Create a new client object for BigQueryWrite.
-
.big_query_write_available?(version: :v1) ⇒ boolean
Determines whether the BigQueryWrite service is supported by the current client.
-
.configure {|::Google::Cloud.configure.bigquery_storage| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-bigquery-storage library.
Class Method Details
.big_query_read(version: :v1, &block) ⇒ ::Object
Create a new client object for BigQueryRead.
By default, this returns an instance of
Google::Cloud::Bigquery::Storage::V1::BigQueryRead::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the BigQueryRead service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
Raises an exception if the currently installed versioned client gem for the given API version does not support the BigQueryRead service. You can determine whether the method will succeed by calling big_query_read_available?.
About BigQueryRead
BigQuery Read API.
The Read API can be used to read data from BigQuery.
75 76 77 78 79 80 81 82 83 84 |
# File 'lib/google/cloud/bigquery/storage.rb', line 75 def self.big_query_read version: :v1, &block require "google/cloud/bigquery/storage/#{version.to_s.downcase}" package_name = Google::Cloud::Bigquery::Storage .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Bigquery::Storage.const_get(package_name).const_get(:BigQueryRead) service_module.const_get(:Client).new(&block) end |
.big_query_read_available?(version: :v1) ⇒ boolean
Determines whether the BigQueryRead service is supported by the current client. If true, you can retrieve a client object by calling big_query_read. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the BigQueryRead service, or if the versioned client gem needs an update to support the BigQueryRead service.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/google/cloud/bigquery/storage.rb', line 97 def self.big_query_read_available? version: :v1 require "google/cloud/bigquery/storage/#{version.to_s.downcase}" package_name = Google::Cloud::Bigquery::Storage .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Bigquery::Storage.const_get package_name return false unless service_module.const_defined? :BigQueryRead service_module = service_module.const_get :BigQueryRead service_module.const_defined? :Client rescue ::LoadError false end |
.big_query_write(version: :v1, &block) ⇒ ::Object
Create a new client object for BigQueryWrite.
By default, this returns an instance of
Google::Cloud::Bigquery::Storage::V1::BigQueryWrite::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the BigQueryWrite service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
Raises an exception if the currently installed versioned client gem for the given API version does not support the BigQueryWrite service. You can determine whether the method will succeed by calling big_query_write_available?.
About BigQueryWrite
BigQuery Write API.
The Write API can be used to write data to BigQuery.
For supplementary information about the Write API, see: https://cloud.google.com/bigquery/docs/write-api
141 142 143 144 145 146 147 148 149 150 |
# File 'lib/google/cloud/bigquery/storage.rb', line 141 def self.big_query_write version: :v1, &block require "google/cloud/bigquery/storage/#{version.to_s.downcase}" package_name = Google::Cloud::Bigquery::Storage .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Bigquery::Storage.const_get(package_name).const_get(:BigQueryWrite) service_module.const_get(:Client).new(&block) end |
.big_query_write_available?(version: :v1) ⇒ boolean
Determines whether the BigQueryWrite service is supported by the current client. If true, you can retrieve a client object by calling big_query_write. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the BigQueryWrite service, or if the versioned client gem needs an update to support the BigQueryWrite service.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/google/cloud/bigquery/storage.rb', line 163 def self.big_query_write_available? version: :v1 require "google/cloud/bigquery/storage/#{version.to_s.downcase}" package_name = Google::Cloud::Bigquery::Storage .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Bigquery::Storage.const_get package_name return false unless service_module.const_defined? :BigQueryWrite service_module = service_module.const_get :BigQueryWrite service_module.const_defined? :Client rescue ::LoadError false end |
.configure {|::Google::Cloud.configure.bigquery_storage| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-bigquery-storage library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
207 208 209 210 211 |
# File 'lib/google/cloud/bigquery/storage.rb', line 207 def self.configure yield ::Google::Cloud.configure.bigquery_storage if block_given? ::Google::Cloud.configure.bigquery_storage end |